==> pluxml_5.3.orig.tar.gz: PluXml-5.3/core/lang/it/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Italiano',

# common
'L_PLUXML_VERSION'				=> 'PluXml versione',
'L_HOMEPAGE'					=> 'Homepage',
'L_UNCLASSIFIED'				=> 'Non classificato',
'L_INFO_PHP_VERSION'			=> 'Versione di php',
'L_INFO_MAGIC_QUOTES'			=> 'Stato delle "magic quotes"',
'L_INFO_CHARSET'				=> 'encoding',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Tema principale non trovato',
'L_ERR_FILE_NOTFOUND'			=> 'File index non trovato',
'L_ERR_PAGE_NOT_FOUND'			=> 'Pagina non trovata',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'genn',
'L_SHORT_FEBRUARY'				=> 'febbr',
'L_SHORT_MARCH'					=> 'mar',
'L_SHORT_APRIL'					=> 'apr',
'L_SHORT_MAY'					=> 'magg',
'L_SHORT_JUNE'					=> 'guigno',
'L_SHORT_JULY'					=> 'luglio',
'L_SHORT_AUGUST'				=> 'ag',
'L_SHORT_SEPTEMBER'				=> 'sett',
'L_SHORT_OCTOBER'				=> 'ott',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dic',
'L_JANUARY'						=> 'gennaio',
'L_FEBRUARY'					=> 'febbraio',
'L_MARCH'						=> 'marzo',
'L_APRIL'						=> 'aprile',
'L_MAY'							=> 'mggio',
'L_JUNE'						=> 'giugno',
'L_JULY'						=> 'luglio',
'L_AUGUST'						=> 'agosto',
'L_SEPTEMBER'					=> 'settembre',
'L_OCTOBER'						=> 'ottobre',
'L_NOVEMBER'					=> 'novembre',
'L_DECEMBER'					=> 'dicembre',
'L_MONDAY'						=> 'lunedì',
'L_TUESDAY'						=> 'martedì',
'L_WEDNESDAY'					=> 'mercoledì',
'L_THURSDAY'					=> 'giovedì',
'L_FRIDAY'						=> 'venerdì',
'L_SATURDAY'					=> 'sabato',
'L_SUNDAY'						=> 'domenica',

# class.plx.capcha.php
'L_LAST'						=> 'ultima',
'L_FIRST'						=> 'prima',
'L_SECOND'						=> 'seconda',
'L_THIRD'						=> 'terza',
'L_FOURTH'						=> 'quarta',
'L_FIFTH'						=> 'quinta',
'L_SIXTH'						=> 'sesta',
'L_SEVENTH'						=> 'settima',
'L_EIGTH'						=> 'ottava',
'L_NINTH'						=> 'nona',
'L_TENTH'						=> 'decima',
'L_NTH'							=> 'esima',
'L_CAPCHA_QUESTION'				=> 'Qual\'è la <span class="capcha-letter">%s</span> lettera della parola <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s è accessibile in scrittura',
'L_WRITE_NOT_ACCESS'			=> '%s non è accessibile in scrittura o non esiste',
'L_MODREWRITE_AVAILABLE'		=> 'Modulo mod_rewrite disponibile',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Modulo mod_rewrite non disponibile',
'L_LIBGD_INSTALLED'				=> 'Biblioteca GD installata',
'L_LIBGD_NOT_INSTALLED'			=> 'Biblioteca GD non installata',
'L_MAIL_AVAILABLE'				=> 'Funzione di invio mail disponible',
'L_MAIL_NOT_AVAILABLE'			=> 'Funzione di invio mail non disponible',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'Il file "%sversion" è necessario al funzionamento di PluXml',
'L_ARTICLE_NO_TAG'				=> 'Nessun articolo per questo tag !',
'L_UNKNOWN_CATEGORY'			=> 'Questa categoria non esiste !',
'L_NO_ARTICLE_PAGE'				=> 'Nessun articolo per questa pagina !',
'L_UNKNOWN_ARTICLE'				=> 'Questo articolo non esiste o non è più disponibile !',
'L_COM_IN_MODERATION'			=> 'Il commento è in corso di moderazione',
'L_UNKNOWN_STATIC'				=> 'Questa pagina non esiste o non è più disponibile !',
'L_DOCUMENT_NOT_FOUND'			=> 'Il documento specificato non esiste',
'L_NEWCOMMENT_ERR'				=> 'Errore durante la pubblicazione del commento',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Compilare tutti i campi obbligatori',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Verifica anti-spam fallita',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compressione %s attivata',
'L_PAGETITLE_ARCHIVES'			=> 'Archivio',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'nessuna categoria',
'L_CATEGORY'					=> 'categoria',
'L_CATEGORIES'					=> 'categorie',
'L_NO_ARTICLE'					=> 'nessun articolo',
'L_ARTICLE'						=> 'articolo ',
'L_ARTICLES'					=> 'articoli',
'L_ARTAUTHOR_UNKNOWN'			=> 'sconosciuto',
'L_ARTTAGS_NONE'				=> 'nessuno',
'L_ARTCHAPO'					=> 'Leggi il contenuto di #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Feed degli articoli di questa categoria',
'L_ARTFEED_RSS_TAG'				=> 'Feed degli articoli di questo tag',
'L_ARTFEED_RSS'					=> 'Feed degli articoli',
'L_NO_COMMENT'					=> 'Nessun commento',
'L_COMMENT'						=> 'commento',
'L_COMMENTS'					=> 'commenti',
'L_COMFEED_RSS_ARTICLE'			=> 'Feed dei commenti di questo articolo',
'L_COMFEED_RSS'					=> 'Feed dei commenti',
'L_STATICCONTENT_INPROCESS'		=> 'Questa pagina è in corso di redazione',
'L_SAID'						=> 'ha detto',

'L_PAGINATION_FIRST_TITLE'		=> 'Vai alla prima pagina',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Pagina precedente',
'L_PAGINATION_PREVIOUS'			=> 'precedente',
'L_PAGINATION_NEXT_TITLE'		=> 'Vai all\'ultima pagina',
'L_PAGINATION_NEXT'				=> 'successivo',
'L_PAGINATION_LAST_TITLE'		=> 'Aller à la dernière page',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'pagina %s su %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Gli URL privati non sono stati configurati !',
'L_FEED_COMMENTS'				=> 'Commenti',
'L_FEED_ONLINE_COMMENTS'		=> 'Commenti online',
'L_FEED_OFFLINE_COMMENTS'		=> 'Commenti offline',
'L_FEED_WRITTEN_BY'				=> 'Pubblicato da',

);
?>

==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/it/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Italiano',

# common
'L_PLUXML_VERSION'				=> 'PluXml versione',
'L_HOMEPAGE'					=> 'Homepage',
'L_UNCLASSIFIED'				=> 'Non classificato',
'L_INFO_PHP_VERSION'			=> 'Versione di php',
'L_INFO_MAGIC_QUOTES'			=> 'Stato delle "magic quotes"',
'L_INFO_CHARSET'				=> 'encoding',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Tema principale non trovato',
'L_ERR_FILE_NOTFOUND'			=> 'File index non trovato',
'L_ERR_PAGE_NOT_FOUND'			=> 'Pagina non trovata',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'gen',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'mar',
'L_SHORT_APRIL'					=> 'apr',
'L_SHORT_MAY'					=> 'mag',
'L_SHORT_JUNE'					=> 'gui',
'L_SHORT_JULY'					=> 'lug',
'L_SHORT_AUGUST'				=> 'ago',
'L_SHORT_SEPTEMBER'				=> 'set',
'L_SHORT_OCTOBER'				=> 'ott',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dic',
'L_JANUARY'						=> 'gennaio',
'L_FEBRUARY'					=> 'febbraio',
'L_MARCH'						=> 'marzo',
'L_APRIL'						=> 'aprile',
'L_MAY'							=> 'mggio',
'L_JUNE'						=> 'giugno',
'L_JULY'						=> 'luglio',
'L_AUGUST'						=> 'agosto',
'L_SEPTEMBER'					=> 'settembre',
'L_OCTOBER'						=> 'ottobre',
'L_NOVEMBER'					=> 'novembre',
'L_DECEMBER'					=> 'dicembre',
'L_MONDAY'						=> 'lunedì',
'L_TUESDAY'						=> 'martedì',
'L_WEDNESDAY'					=> 'mercoledì',
'L_THURSDAY'					=> 'giovedì',
'L_FRIDAY'						=> 'venerdì',
'L_SATURDAY'					=> 'sabato',
'L_SUNDAY'						=> 'domenica',

# class.plx.capcha.php
'L_LAST'						=> 'ultima',
'L_FIRST'						=> 'prima',
'L_SECOND'						=> 'seconda',
'L_THIRD'						=> 'terza',
'L_FOURTH'						=> 'quarta',
'L_FIFTH'						=> 'quinta',
'L_SIXTH'						=> 'sesta',
'L_SEVENTH'						=> 'settima',
'L_EIGTH'						=> 'ottava',
'L_NINTH'						=> 'nona',
'L_TENTH'						=> 'decima',
'L_NTH'							=> 'esima',
'L_CAPCHA_QUESTION'				=> 'Qual\'è la <span class="capcha-letter">%s</span> lettera della parola <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s è accessibile in scrittura',
'L_WRITE_NOT_ACCESS'			=> '%s non è accessibile in scrittura o non esiste',
'L_MODREWRITE_AVAILABLE'		=> 'Modulo mod_rewrite disponibile',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Modulo mod_rewrite non disponibile',
'L_LIBGD_INSTALLED'				=> 'Biblioteca GD installata',
'L_LIBGD_NOT_INSTALLED'			=> 'Biblioteca GD non installata',
'L_MAIL_AVAILABLE'				=> 'Funzione di invio mail disponible',
'L_MAIL_NOT_AVAILABLE'			=> 'Funzione di invio mail non disponible',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'Il file "%sversion" è necessario al funzionamento di PluXml',
'L_ARTICLE_NO_TAG'				=> 'Nessun articolo per questo tag !',
'L_UNKNOWN_CATEGORY'			=> 'Questa categoria non esiste !',
'L_NO_ARTICLE_PAGE'				=> 'Nessun articolo per questa pagina !',
'L_UNKNOWN_ARTICLE'				=> 'Questo articolo non esiste o non è più disponibile !',
'L_COM_IN_MODERATION'			=> 'Il commento è in corso di moderazione',
'L_UNKNOWN_STATIC'				=> 'Questa pagina non esiste o non è più disponibile !',
'L_DOCUMENT_NOT_FOUND'			=> 'Il documento specificato non esiste',
'L_NEWCOMMENT_ERR'				=> 'Errore durante la pubblicazione del commento',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Compilare tutti i campi obbligatori',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Verifica anti-spam fallita',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compressione %s attivata',
'L_PAGETITLE_ARCHIVES'			=> 'Archivio',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'nessuna categoria',
'L_CATEGORY'					=> 'categoria',
'L_CATEGORIES'					=> 'categorie',
'L_NO_ARTICLE'					=> 'nessun articolo',
'L_ARTICLE'						=> 'articolo ',
'L_ARTICLES'					=> 'articoli',
'L_ARTAUTHOR_UNKNOWN'			=> 'sconosciuto',
'L_ARTTAGS_NONE'				=> 'nessuno',
'L_ARTCHAPO'					=> 'Continua...',
'L_ARTFEED_RSS_CATEGORY'		=> 'Feed degli articoli di questa categoria',
'L_ARTFEED_RSS_TAG'				=> 'Feed degli articoli di questo tag',
'L_ARTFEED_RSS'					=> 'Feed degli articoli',
'L_NO_COMMENT'					=> 'Nessun commento',
'L_COMMENT'						=> 'commento',
'L_COMMENTS'					=> 'commenti',
'L_COMFEED_RSS_ARTICLE'			=> 'Feed dei commenti di questo articolo',
'L_COMFEED_RSS'					=> 'Feed dei commenti',
'L_STATICCONTENT_INPROCESS'		=> 'Questa pagina è in corso di redazione',
'L_SAID'						=> 'ha detto',

'L_PAGINATION_FIRST_TITLE'		=> 'Vai alla prima pagina',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Pagina precedente',
'L_PAGINATION_PREVIOUS'			=> 'precedente',
'L_PAGINATION_NEXT_TITLE'		=> 'Pagina seguente',
'L_PAGINATION_NEXT'				=> 'successivo',
'L_PAGINATION_LAST_TITLE'		=> 'Vai all\'ultima pagina',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'pagina %s su %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Gli URL privati non sono stati configurati !',
'L_FEED_COMMENTS'				=> 'Commenti',
'L_FEED_ONLINE_COMMENTS'		=> 'Commenti online',
'L_FEED_OFFLINE_COMMENTS'		=> 'Commenti chiusi',
'L_FEED_WRITTEN_BY'				=> 'Pubblicato da',

);
?>
